"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports.polyfillImageServiceDevRoutes = polyfillImageServiceDevRoutes;
exports.addImageRoutes = addImageRoutes;

var _path = _interopRequireDefault(require("path"));

var _fsExtra = _interopRequireDefault(require("fs-extra"));

var _fetchRemoteFile = require("gatsby-core-utils/fetch-remote-file");

var _hasFeature = require("../has-feature");

var _mimeTypeHelpers = require("./utils/mime-type-helpers");

var _transformImages = require("./transform-images");

function polyfillImageServiceDevRoutes(app) {
  if ((0, _hasFeature.hasFeature)(`image-cdn`)) {
    return;
  }

  addImageRoutes(app);
}

function addImageRoutes(app) {
  app.get(`/_gatsby/file/:url/:filename`, async (req, res) => {
    var _global$__GATSBY;

    // remove the file extension
    const url = req.params.url;

    const outputDir = _path.default.join(((_global$__GATSBY = global.__GATSBY) === null || _global$__GATSBY === void 0 ? void 0 : _global$__GATSBY.root) || process.cwd(), `public`, `_gatsby`, `file`);

    const filePath = await (0, _fetchRemoteFile.fetchRemoteFile)({
      directory: outputDir,
      url: url,
      name: req.params.filename
    });

    _fsExtra.default.createReadStream(filePath).pipe(res);
  });
  app.get(`/_gatsby/image/:url/:params/:filename`, async (req, res) => {
    var _global$__GATSBY2;

    const {
      params,
      url,
      filename
    } = req.params;
    const searchParams = new URLSearchParams(Buffer.from(params, `base64`).toString());
    const resizeParams = {
      width: 0,
      height: 0,
      quality: 75,
      format: ``
    };

    for (const [key, value] of searchParams) {
      switch (key) {
        case `w`:
          {
            resizeParams.width = Number(value);
            break;
          }

        case `h`:
          {
            resizeParams.height = Number(value);
            break;
          }

        case `fm`:
          {
            resizeParams.format = value;
            break;
          }

        case `q`:
          {
            resizeParams.quality = Number(value);
            break;
          }
      }
    }

    const remoteUrl = Buffer.from(url, `base64`).toString();

    const outputDir = _path.default.join(((_global$__GATSBY2 = global.__GATSBY) === null || _global$__GATSBY2 === void 0 ? void 0 : _global$__GATSBY2.root) || process.cwd(), `public`, `_gatsby`, `_image`, url);

    const filePath = await (0, _transformImages.transformImage)({
      outputDir,
      args: {
        url: remoteUrl,
        filename,
        ...resizeParams
      }
    });
    res.setHeader(`content-type`, (0, _mimeTypeHelpers.getFileExtensionFromMimeType)(_path.default.extname(filename)));

    _fsExtra.default.createReadStream(filePath).pipe(res);
  });
  return app;
}