"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports.shouldDispatch = shouldDispatch;
exports.dispatchLocalFileServiceJob = dispatchLocalFileServiceJob;
exports.dispatchLocalImageServiceJob = dispatchLocalImageServiceJob;

var _path = _interopRequireDefault(require("path"));

var _importFrom = _interopRequireDefault(require("import-from"));

var _mimeTypeHelpers = require("../utils/mime-type-helpers");

var _getGatsbyVersion = require("../utils/get-gatsby-version");

var _urlGenerator = require("../utils/url-generator");

function shouldDispatch() {
  return !(process.env.GATSBY_CLOUD_IMAGE_CDN === `1` || process.env.GATSBY_CLOUD_IMAGE_CDN === `true`) && process.env.NODE_ENV === `production`;
}

function dispatchLocalFileServiceJob({
  url,
  mimeType,
  contentDigest
}, store) {
  var _global$__GATSBY$root, _global$__GATSBY, _global$__GATSBY2;

  const GATSBY_VERSION = (0, _getGatsbyVersion.getGatsbyVersion)();
  const publicUrl = (0, _urlGenerator.generatePublicUrl)({
    url,
    // We always want file based url
    mimeType
  }, false).split(`/`);
  const extension = (0, _mimeTypeHelpers.getFileExtensionFromMimeType)(mimeType); // eslint-disable-next-line @typescript-eslint/no-non-null-assertion

  const filename = publicUrl.pop();
  publicUrl.unshift(`public`);
  const {
    actions
  } = (0, _importFrom.default)((_global$__GATSBY$root = (_global$__GATSBY = global.__GATSBY) === null || _global$__GATSBY === void 0 ? void 0 : _global$__GATSBY.root) !== null && _global$__GATSBY$root !== void 0 ? _global$__GATSBY$root : process.cwd(), `gatsby/dist/redux/actions`); // @ts-ignore - we dont have correct typings for this

  actions.createJobV2({
    name: `FILE_CDN`,
    inputPaths: [],
    // we know it's an image so we just mimic an image
    outputDir: _path.default.join(((_global$__GATSBY2 = global.__GATSBY) === null || _global$__GATSBY2 === void 0 ? void 0 : _global$__GATSBY2.root) || process.cwd(), publicUrl.filter(Boolean).join(`/`)),
    args: {
      url,
      filename: `${filename}.${extension}`,
      contentDigest
    }
  }, {
    name: `gatsby`,
    version: GATSBY_VERSION,
    resolve: __dirname
  })(store.dispatch, store.getState);
}

function dispatchLocalImageServiceJob({
  url,
  extension,
  basename,
  width,
  height,
  format,
  fit,
  contentDigest,
  quality
}, store) {
  var _global$__GATSBY$root2, _global$__GATSBY3, _global$__GATSBY4;

  const GATSBY_VERSION = (0, _getGatsbyVersion.getGatsbyVersion)();
  const publicUrl = (0, _urlGenerator.generatePublicUrl)({
    url,
    mimeType: `image/${extension}`
  }).split(`/`);
  publicUrl.unshift(`public`); // We need to use import-from to remove circular dependency

  const actions = (0, _importFrom.default)((_global$__GATSBY$root2 = (_global$__GATSBY3 = global.__GATSBY) === null || _global$__GATSBY3 === void 0 ? void 0 : _global$__GATSBY3.root) !== null && _global$__GATSBY$root2 !== void 0 ? _global$__GATSBY$root2 : process.cwd(), `gatsby/dist/redux/actions`); // @ts-ignore - importFrom doesn't work with types

  actions.createJobV2({
    name: `IMAGE_CDN`,
    inputPaths: [],
    outputDir: _path.default.join(((_global$__GATSBY4 = global.__GATSBY) === null || _global$__GATSBY4 === void 0 ? void 0 : _global$__GATSBY4.root) || process.cwd(), publicUrl.filter(Boolean).join(`/`), (0, _urlGenerator.generateImageArgs)({
      width,
      height,
      format,
      quality
    })),
    args: {
      url,
      filename: `${basename}.${extension}`,
      width,
      height,
      format,
      fit,
      quality,
      contentDigest
    }
  }, {
    name: `gatsby`,
    version: GATSBY_VERSION,
    resolve: __dirname
  })(store.dispatch, store.getState);
}